/****************************************************************************
 AIAddinStateManager.h
 
 Copyright (c) Microsoft Corporation
 
 Records addin state that isn't passed through the API pipeline
 
 *****************************************************************************/

#import <Foundation/Foundation.h>
#import "AIMessage.h"
#import "AIOutlookPermissionLevel.h"

@interface AIAddinStateManager : NSObject

+ (instancetype _Nonnull)shared;

/**
 *  Gets the doc cookie from the message
 *
 *  @param message The message to get the doc cookie from
 *
 *  @return Some unique value for the message for this run of the app
 */
- (long)docCookieForMessage:(id<AIMessage> _Nonnull)message;

/**
 *  Gets the doc cookie from the exchange ID of a message
 *
 *  @param exchangeId The unique identifier for this message on exchange
 *
 *  @return Some unique value for the message for this run of the app
 */
- (long)docCookieForExchangeId:(NSString * _Nonnull)exchangeId;

/**
 *  Returns the exchange ID for a message, given the doc cookie
 *
 *  @param docCookie The doc cookie of the message
 *
 *  @return The Exchange ID of the message
 */
- (NSString * _Nullable)exchangeIdForDocCookie:(long)docCookie;

/**
 *  Records an outlook permission for a given solution id
 *
 *  @param permission The permission to store
 *  @param solutionId The solution id to store the permission for
 */
- (void)setOutlookPermission:(AIOutlookPermissionLevel)permission forSolutionId:(NSString * _Nonnull)solutionId;

/**
 *  Returns a previously stored outlook permission for a solution id.
 *
 *  If the permission has not been set previously, Restricted will be returned
 *
 *  @param solutionId Solution id to use as the key to look up
 *
 *  @return An outlook permission level
 */
- (AIOutlookPermissionLevel)outlookPermissionForSolutionId:(NSString * _Nonnull)solutionId;


@end
