/****************************************************************************
 AIApiErrorCode.h
 
 Copyright (c) Microsoft Corporation
 
 API error codes for the AddinsFramework
 
 *****************************************************************************/
#import <Foundation/Foundation.h>

/**
 *  Error domain for use when creating NSErrors
 */
static const NSString *AIApiErrorDomain = @"AIAPIErrorDomain";

/**
 *  Error codes for errors which occur when performing API calls
 */
typedef NS_ENUM(NSUInteger, AIApiErrorCode)
{
	/**
	 *  Used when there is no error
	 */
	AIApiErrorCode_NoError = 0,
	
	/**
	 *  The requested API is unsupported or undefined
	 */
	AIApiErrorCode_UnsupportedApi,
	
	/**
	 *  When requesting a notification be shown, and the key already exists
	 */
	AIApiErrorCode_NotificationKeyAlreadyExists,
	
	/**
	 *  When a notification is requested to be removed, but the key doesn't exist
	 */
	AIApiErrorCode_NotificationKeyNotFound,
	
	/**
	 *  When there are to many notifications showing to display any more
	 */
	AIApiErrorCode_TooManyNotifications,
	
	/**
	 *  Error occured when making an Exchange REST request
	 */
	AIApiErrorCode_ExchangeRESTError,
	
	/**
	 *  A parameter passed to the API was invalid
	 */
	AIApiErrorCode_InvalidParameter,
	
	
	//--------------------------------------------------------------------------
	/**
	 *  Only used for checking that an error code is valid
	 */
	AIApiErrorCode_MaxErrorCode
	
};
