/****************************************************************************
 AIAttachment.h
 
 Copyright (c) Microsoft Corporation
 
 Defines the interface for a mail attachment
 
 *****************************************************************************/

#import <Foundation/Foundation.h>

/**
 * All information about an attachment in a message that may be required by the
 * Addin framework.
 */
@protocol AIAttachment <NSObject>

/**
 * A unique identifier for the attachment.
 *
 * @return A unique identifier for the attachment
 */
//TODO dalemy Check on the format. It seems to be a guid, with other data appended, then base 64 encoded
- (NSString * _Nonnull)identifier; //@"AAMkADk1MWFkMmZmLTQ5NWUtNGMwMy1hNGQyLTNlODU5MDQ3Y2QzMQBGAAAAAADL2TLOgp4kSpHBGzXI6geuBwCFRjOix/a4S6PoZRLM9gy5AAAAAAENAACFRjOix/a4S6PoZRLM9gy5AAA36rTRAAABEgAQAHqwQS6h9Q5Ls7w4MpSa/bM=",

/**
 * The file name for the attachment
 *
 * @return The file name for the attachment
 */
- (NSString * _Nonnull)filename;

/**
 * The MIME type of the content in the attachment
 *
 * @return The MIME type of the content in the attachment
 */
- (NSString * _Nonnull)contentType;

/**
 * The size of the contents of the attachment in bytes
 *
 * @return The size of the contents of the attachment in bytes
 */
- (NSNumber * _Nonnull)contentSize;

/**
 * Checks if the type of the attachment is a file or exchange item
 *
 * @return YES if the attachment is a file, NO if it is an exchange item
 */
- (BOOL)isFile;

/**
 * A flag stating whether the attachment was inline or not
 *
 * @return A flag stating whether the attachment was inline or not
 */
- (BOOL)isInline;

@end

