/****************************************************************************
 AICacheDelegate.h
 
 Copyright (c) Microsoft Corporation
 
 Defines the interface for caching data. The AddinsFramework will call the 
 methods in this protocol to store and retrieve items from a cache.
 
 *****************************************************************************/

#import <Foundation/Foundation.h>

/**
 * This protocol defines the interface for host provided caching
 */
@protocol AICacheDelegate <NSObject>

/**
 *  Returns an object from the cache which corresponds to the supplied key. 
 *  If the key does not exist in the cache, nil is returned.
 *
 *  @param key        The unique identifier for the object
 *  @param completion A block called when the object fetch has completed. The 
 *                    parameters of the block are the key, and the object (if
 *                    found)
 */
- (void)fetchObjectForKey:(NSString * _Nonnull)key completion:(void (^_Nonnull)(NSString * _Nonnull key, id _Nullable object))completion;

/**
 *  Sets an object in the cache for a given key
 *
 *  @param object The object to store in the cache
 *  @param key    The key to associate with the object
 */
- (void)setObject:(id<NSCoding> _Nonnull)object forKey:(NSString * _Nonnull)key;

@end

