/****************************************************************************
 AICommandApp.h
 
 Copyright (c) Microsoft Corporation
 
 Represents a single add-in and it's commands
 
 *****************************************************************************/

#import "AICommandButton.h"

@interface AICommandApp : NSObject
{
	NSMutableArray<AICommandButton *> * _Nullable _commandButtons;
}

/**
 *  Creates a new AICommandApp
 *
 *  @return A new AICommandApp
 */
- (instancetype _Nonnull)init;

/**
 *  Creates a new AICommandApp, with the buttons specified
 *
 *  @param buttons The buttons which are a part of the new AICommandApp
 *
 *  @return A new AICommandApp
 */
- (instancetype _Nonnull)initWithCommandButtons:(NSArray<AICommandButton*> * _Nonnull)buttons;

/**
 *  Gets the URL of the icon of this add-in in the highest resolution possible
 *
 *  @return The URL if the add-ins icon
 */
- (NSURL * _Nullable)iconUrl;

/**
 *  Gets the display name of the add-in
 *
 *  @return The add-ins display name
 */
- (NSString * _Nullable)displayName;

/**
 *  Adds a command button to this app
 *
 *  @param button The command button to be added
 */
- (void)addCommandButton:(AICommandButton * _Nullable)button;

/**
 *  All the command buttons which are part of this app
 *
 *  @return An array of command buttons in this app
 */
- (NSArray<AICommandButton *> * _Nullable)commandButtons;

@end
