/****************************************************************************
 AIErrorCode.h
 
 Copyright (c) Microsoft Corporation
 
 Generic error codes for the AddinsFramework
 
 *****************************************************************************/

#import <Foundation/Foundation.h>

/**
 *  Error domain for use when creating NSErrors
 */
static const NSString *AIErrorDomain = @"AIErrorDomain";

/**
 *  The error codes used by the addin framework
 */
typedef NS_ENUM(NSInteger, AIErrorCode)
{
	/**
	 *  A delegate was missing which must be set before use.
	 */
	AIErrorCode_MissingDelegate,
	
	/**
	 *  No message is currently set
	 */
	AIErrorCode_NoCurrentMessage,
	
	/**
	 *  No account is currently set
	 */
	AIErrorCode_NoCurrentAccount,
	
	/**
	 *  Failed to create the OSF host implementation
	 */
	AIErrorCode_HostCreationFailed,
	
	/**
	 *  Failed to create the framework
	 */
	AIErrorCode_FrameworkCreationFailed,
	
	/**
	 *  Failed to create the app manager
	 */
	AIErrorCode_AppManagerCreationFailed,
	
	/**
	 *  Failed to create/ensure the stores
	 */
	AIErrorCode_StoreCreationFailed,
	
	/**
	 *  Failed to create a provider
	 */
	AIErrorCode_ProviderCreationFailed,
	
	/**
	 *  The current implementation is a dummy
	 */
	AIErrorCode_DummyFramework,
	
};
