/****************************************************************************
 AIIconHandler.h
 
 Copyright (c) Microsoft Corporation
 
 A handler used for downloading images to avoid duplicate downloads
 If a cache manager hasn't been provided to the AIAddinManager, data will be
 persisted in memory only.
 
 *****************************************************************************/

#import <Foundation/Foundation.h>
#import <UIKit/UIkit.h>

@interface AIIconHandler : NSObject

/**
 *  A block which is called on success or failure of fetching an image
 *
 *  @param image A pointer to the returned image if successful, nil otherwise
 */
typedef void (^AIIconHandlerReturnBlock)(UIImage * _Nullable image);

/**
 *  A shared instance of the icon handler
 *
 *  @return A shared instance of the icon handler
 */
+ (instancetype _Nonnull)shared;

/**
 *  Requests an image from the handler.
 *  If the image is not in a backing cache, the handler will fetch the image.
 *
 *  @param url        The URL of the image which is requested
 *  @param completion The block to call with the returned image. 
 */
- (void)imageForURL:(NSURL * _Nullable)url completion:(AIIconHandlerReturnBlock _Nonnull)completion;


@end
