/****************************************************************************
 AIImageCache.h
 
 Copyright (c) Microsoft Corporation
 
 A cache used for downloading images to avoid duplicate downloads
 Only caches for run time currently. Images are not persisted between launches.
 
 *****************************************************************************/

#import <Foundation/Foundation.h>
#import <UIKit/UIkit.h>

@interface AIImageCache : NSObject

/**
 *  A block which is called on success or failure of fetching an image
 *
 *  @param image A pointer to the returned image if successful, nil otherwise
 */
typedef void (^AIImageCacheReturnBlock)(UIImage * _Nullable image);

/**
 *  A shared instance of the image cache
 *
 *  @return A shared instance of the image cache
 */
+ (instancetype _Nonnull)shared;

/**
 *  Requests an image from the cache.
 *  If the image is not in the cache, the cache will fetch the image.
 *
 *  @param url        The URL of the image (used as a key in the cache)
 *  @param completion The block to call with the returned image. 
 */
- (void)imageForURL:(NSURL * _Nullable)url completion:(AIImageCacheReturnBlock _Nonnull)completion;


@end
