/****************************************************************************
 AIProvider.h
 
 Copyright (c) Microsoft Corporation
 
 Defines the interface for a provider. e.g. The class which is called to get 
 information about the manifests available
 
 *****************************************************************************/

#import <Foundation/Foundation.h>
#import "AIStore.h"

/**
 * This protocol defines the interface for getting manifests
 */
@protocol AIProvider <NSObject>

/**
 *  The type of store this provider is for
 *
 *  @return A store type
 */
- (AIStore)storeType;

/**
 *  Id uniquely identifying the store
 *
 *  @return A unique ID for the store
 */
- (NSString * _Nonnull)storeId;

/**
 *  Begin fetching the manifest
 *
 *  @param onCompletion Call this block when the fetch is completed
 */
- (void)fetchManifestsOnCompletion:(void(^ _Nonnull)(BOOL succeeded, NSArray<NSString *> * _Nullable manifests))onCompletion;

@optional

/**
 *  Informs the provider that it is being shut down
 */
- (void)shutdown;

@end

