/****************************************************************************
 AITaskpaneProvider.
 
 Copyright (c) Microsoft Corporation
 
 Defines an interface for the AddinsFramework to request and present a view as
 a "taskpane"
 
 *****************************************************************************/

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>

/**
 * Handles the lifecycle of taskpanes when required by the Addin framework
 */
@protocol AITaskpaneProvider <NSObject>

/**
 * Called by the framework to create a container to display a taskpane in.
 *
 * @return A UIView for the Addin framework to place child views into
 */
- (UIView * _Nonnull)createTaskpaneContainer;

/**
 * Called to inform the host app that the Addin framework wishes this UIView 
 * to be displayed.
 *
 * @param taskpaneContainer The UIView which was provided by the 
 *							[AITaskpaneProvider createTaskpaneContainer] call.
 * @param title				The title of the taskpane
 */
- (void)displayTaskpane:(UIView * _Nonnull)taskpaneContainer withTitle:(NSString * _Nonnull)title;

/**
 * When a taskpane is created, a callback will be registered with the host 
 * application for it to call when the user closes the taskpane
 *
 * @param closeCallback		The callback to call when the user closes the
 *							taskpane
 * @param taskpaneContainer	The taskpane container for which this callback
 *							should be registered
 */
- (void)registerCallback:(void (^ _Nonnull)())closeCallback forTaskpaneClose:(UIView * _Nonnull)taskpaneContainer;

@end

