//
// Intended for use with MarkupTextView to enable editing of
// content in WKWebView and for communicating updates back
// to MarkupTextView.
//
// Message Handlers:
//
// - textChange: provides the updated HTML document on text updates
//

function init() {
  // Keep a copy of the original document so that we don't
  // pollute the original content with DOM changes required
  // for editing
  var parser = new DOMParser();
  var originalDoc = parser.parseFromString(document.documentElement.outerHTML, "text/html");

  setViewport(); // Ensure view fits
  setStyles();
  enableEditingInBody();

  var observerHandler = function(mutations) {
    // Replace original document body with edited body
    bodyForDocument(originalDoc).innerHTML = bodyForDocument(document).innerHTML;

    var html = originalDoc.documentElement.outerHTML;

    // Notify WKWebView of change
    window.webkit.messageHandlers.textChange.postMessage(html);
  };

  observeBodyUpdates(observerHandler);
}

function bodyForDocument(doc) {
  return doc.getElementsByTagName('body')[0];
}

function setViewport() {
  var viewport = document.querySelector("meta[name=viewport]") || document.createElement('meta');
  viewport.setAttribute('name', 'viewport');
  viewport.setAttribute('content', 'width=device-width');

  var documentHead = document.getElementsByTagName('head')[0];
  documentHead.appendChild(viewport);
}

function setStyles() {
  var stylesheet = document.createElement('style');

  var styles = "html { -webkit-tap-highlight-color: rgba(0, 0, 0, 0); }" // To remove gray highlight when tapping on webView
  styles += "body { color: #333; line-height: 150%; font-family: '-apple-system','HelveticaNeue'; }"
  stylesheet.innerHTML = styles

  var documentHead = document.getElementsByTagName('head')[0];
  documentHead.appendChild(stylesheet);
}

function enableEditingInBody() {
  var body = bodyForDocument(document);
  body.setAttribute('contentEditable', 'true');
}

function observeBodyUpdates(observerHandler) {
  var body = bodyForDocument(document);
  var observer = new window.WebKitMutationObserver(observerHandler);

  observer.observe(body, {
    subtree: true,
    characterData: true,
    childList: true
  });
}

init();
