

// override these values to configure the webview
var config = { screenWidth: 0, textZoom: 0, userScalable: false, interceptLinkLongTap: true };

// when activeLoading = 0, all onLoad callbacks finished and we send notification to iOS app
var activeLoading = 1;/*DOMContentLoaded*/
var redoCount = 10;
var redoCount_copy = 0;
var redoTimer = null;
var milliseconds = 500;
var timerScheduled = false
var timerInProgress = false

function PlusPlus()
{
  activeLoading++;
}

function MinusMinus()
{
  activeLoading--;
}

function redoTimerFunc()
{
  timerInProgress = true;
  if (redoTimer != null)
  {
    window.clearTimeout(redoTimer)
    redoTimer = null;
  }
  sendNotificationHelper(--redoCount_copy);
  if (timerScheduled)
  {
    redoTimerFunc();
  }
  else
  {
    if (redoCount_copy != 0)
    {
      redoTimer = window.setTimeout("redoTimerFunc();", milliseconds);
    }
  }
  timerInProgress = false;
}

function sendNotificationHelper(redoCount)
{
  var width = document.body.getBoundingClientRect().right;
  window.location = 'watchkit:objects='+activeLoading+'&width='+document.body.scrollWidth+'&height='+parseInt(document.body.scrollHeight*(config.screenWidth*1.0 / width))+'&redoCount='+redoCount;
}

function sendNotification()
{
  if (redoTimer != null)
  {
    window.clearTimeout(redoTimer)
    redoTimer = null;
  }
  redoCount_copy = redoCount;
  if (!timerInProgress)
  {
    redoTimer = window.setTimeout("redoTimerFunc();", 0);
  }
  else
  {
    timerScheduled = true
  }
}

// do the heavy-lifting once all the content has been loaded
document.addEventListener("DOMContentLoaded", function(event) {
    console.log("DOM fully loaded and parsed");
    scaleMessage(config);
    MinusMinus();
    sendNotification();
});

// look for newly added elements to handle long-tap on anchor tags (anchors can get added after-the-fact w/ Apple's data detectors)
// Consider doing this with MutationObservers for better performance (OG couldn't get this working)
document.addEventListener("DOMNodeInserted", function(e) {
    var node  = e.target;
    console.log("DOM node added: " + node);
}, false);


// this lays out the rest of the 
var scaleMessage = function(config) {

    // The order of operations is important

    // 1. fix up some of the css
    insertStyles(config.textZoom, config.font);

    // 2. adjust the viewport width to force the page to relayout
    adjustViewport(config.screenWidth);

    // 3. after the page has layed out (post viewport change), adjust the viewport size to make sure everything is visible
    adjustScaling(config.screenWidth, config.userScalable);
}

// add some basic styles to make things look nicer
var insertStyles = function(textZoom, font) {

    console.log('insertStyles()');

    var s = document.createElement('style');
    s.setAttribute('type', 'text/css');
    
    var css = '';

    css += 'html { background: #FFFFFF; }';        // make sure the background is always white
    css += 'body { padding: 4px; }';            // set the padding to 4px (use padding so inner elements can layout properly)
    css += 'body { margin: 0; }';               // set the margin to 0
    css += 'a { word-wrap: break-word; word-wrap: break-word; -webkit-nbsp-mode: space; -webkit-line-break: after-white-space; }';      // forces links to break after edge of the screen
    css += 'p { word-wrap: break-word; }';      // forces paragraphs to break after edge of the screen
    css += 'hr { width: 100% !important; }';    // don't let horizontal rules stretch the screen
    css += 'blockquote { margin: 0px 10px !important; }';       // override the margin for blockquotes since these often get nested and become very skinny
    css += 'body { color: #000000;}';       // colors & line height

    // fonts       
    css += 'body { font-family: \''+font+'\'; font-size: 9pt; word-wrap: break-word; -webkit-nbsp-mode: space; -webkit-line-break: after-white-space;   }';

    css += 'body { -webkit-text-size-adjust: none }';

    s.appendChild(document.createTextNode(css));

    // insert the style tag as early as possible so emails can override it if they choose too
    var head = getOrCreateHeadForDocument(document);
    head.insertBefore(s, head.children.length > 0 ? head.children[0] : null);
}

// layout the page once to force any stylesheets to be applied
var adjustViewport = function(screenWidth) {
    var viewportContentWidth = 'width=' + screenWidth;

    // get the viewport
    var head = getOrCreateHeadForDocument(document);
    var viewport = document.querySelector("meta[name=viewport]");

    // update the viewport
    if (viewport) {
        viewport.setAttribute('content', viewportContentWidth);
    }
    else {
        var meta = document.createElement('meta');
        meta.setAttribute('name', 'viewport');
        meta.setAttribute('content', viewportContentWidth);
        head.appendChild(meta);
    }

    console.log('adjusted viewport width: ' + viewportContentWidth);
}

// finds the largest table in the email and adjusts the meta viewport scale to fit it nicely
var adjustScaling = function(screenWidth, userScalable) {

    console.log('adjustScaling(' + userScalable + ')');

    var widest = screenWidth;

    // track if we scaled due to table or not
    var tableCausedScale = false;

    // consider scaling emails with tables
    var tables = document.getElementsByTagName('table');
    for (var i = 0; i < tables.length; i++) {

        var t = tables[i];

        // get the computed width of the table, taking into account all of it's subelements
        var width = t.getBoundingClientRect().right;
        width += parseInt(window.getComputedStyle(t).getPropertyValue('padding-right'));
        width += parseInt(window.getComputedStyle(t).getPropertyValue('margin-right'));

        console.log('table width: ' + width + ' (widest: ' + widest + ')'); 
        if (width > widest) {
            tableCausedScale = true;
            widest = width;
        }
    }

    var width = document.body.getBoundingClientRect().right;

    console.log('body width: ' + width + ' (widest: ' + widest + ')');
    if (width > widest) {
        widest = width;
    }
    var needsScale = screenWidth < widest;
    console.log('needsScale: ' + (needsScale ? 'true' : 'false' ) + ' (screenWidth: ' + screenWidth + ' vs widest: ' + widest + ')');

    // craft viewport meta tag
    var viewportContentWidth = 'width=' + (needsScale ? widest : screenWidth);
    var viewportScalable = 'user-scalable=' + (userScalable ? 'yes' : 'no');
    var ratio = screenWidth*1.0 / widest;
    var scaleItself = 'minimum-scale='+ratio+', maximum-scale='+ratio+', initial-scale=1.0';
    newViewport = viewportContentWidth + ', ' + viewportScalable;
    if (needsScale)
    {
      newViewport += ', '+scaleItself;
    }

    // set the viewport
    var head = getOrCreateHeadForDocument(document);
    var viewport = document.querySelector("meta[name=viewport]");

    if (viewport) {
        viewport.setAttribute('content', newViewport);
    }
    else {
        var meta = document.createElement('meta');
        meta.setAttribute('name', 'viewport');
        meta.setAttribute('content', newViewport);
        head.appendChild(meta);
    }

    console.log('adjusted viewport: ' + newViewport);

    if (needsScale && !tableCausedScale) {
        // if we scaled but it wasn't due to wide table, then resize all images to fit inside the body
        console.log('need to resize wide images');
        resizeWideImages(config.screenWidth);
    }
    else
    {
      noResizeImages((needsScale ? widest : screenWidth));
    }
}

var noResizeImages = function(width) {
  
  console.log('noResizeWideImages()');
  var imgs = document.getElementsByTagName('img');
  for (var i = 0; i < imgs.length; i++) {
    if (!imgs[i].complete) {
      if (imgs[i].onload == null)
      {
        PlusPlus();
        var iimg = imgs[i];
        imgs[i].onload = function() {
          scaleMessage(config);
          MinusMinus();
          sendNotification();
        }
      }
    } else
    {
      resizeImage(imgs[i], width);
    }
  }
}

// loops through and finds images wider than the body and resizes them to fit
// we shouldn't call this on HTML emails since often they have larger images on purpose
var resizeWideImages = function(screenWidth) {
    console.log('resizeWideImages()');
    var imgs = document.getElementsByTagName('img');
    for (var i = 0; i < imgs.length; i++) {
        resizeImage(imgs[i], screenWidth);
    }
}

// resize image if it's been loaded, otherwise attach a handler to resize in the future
var resizeImage = function(img, bodyWidth) {

    console.log('img-complete: ' + img.complete + ', bodyWidth: ' + bodyWidth);
    if (img.complete) {

        var origWidth = parseInt(window.getComputedStyle(img, null).getPropertyValue('width'));

        // try to fit the element inside of it's parent element
        var newWidth = img.parentNode.getBoundingClientRect().width;

        // if it's still too large to fit the screen, resize further
        if (newWidth > bodyWidth) {
            var x = getPosition(img).x; // calculate the left-margin to find out how much leeway we have to render this image
            newWidth = bodyWidth - x;
        }

        if (origWidth > newWidth) {
            var origHeight = parseInt(window.getComputedStyle(img, null).getPropertyValue('height'));
            var newHeight = Math.ceil(origHeight * newWidth / origWidth); // Note: if the image is embedded in other stuff, it will still be too large
            img.style.width = newWidth + 'px';
            img.style.height = newHeight + 'px';
        }

    }
    else {

        // image isn't ready, attach a handler to process it when complete
        if (img.onload == null)
        {
          PlusPlus();
          img.onload = function() {
              console.log('temp callback');
              scaleMessage(config);
              MinusMinus();
              sendNotification();
          }
        }
    }
}

// get the head or create one if it's missing (is that even possible?)
var getOrCreateHeadForDocument = function(doc) {
	var heads = doc.getElementsByTagName('head');
	var head;
	if (heads.length == 0) {
		head = doc.createElement('head');
		doc.body.insertBefore(head, body); 
	}
	else {
		head = heads[0];
	}
	return head;
}

// use this to get the true position of an element
var getPosition = function(element) {

    var xPosition = 0;
    var yPosition = 0;
  
    while(element) {
        xPosition += (element.offsetLeft - element.scrollLeft + element.clientLeft);
        yPosition += (element.offsetTop - element.scrollTop + element.clientTop);
        element = element.offsetParent;
    }
    return { x: xPosition, y: yPosition };
}
